Learn R Programming

lactater (version 0.2.0)

bsln_plus_helper: Bsln+ helper

Description

For internal use only and it won't be exported.

Usage

bsln_plus_helper(.data, data_augmented, fit, model, plus)

Value

The results (intensity, lactate, heart rate) from the lactate threshold method.

Arguments

.data

The raw data.

data_augmented

The augmented data from the model.

fit

The fit you would like to use for finding the lactate values associated to each one of the lactate thresholds.

model

The model chosen in fit,

plus

The plus value to be added to the baseline value.