For internal use only and it won't be exported.
helper_dmax_log_poly_moddmax(data_prepared, sport, loglog_restrainer, plot)The data retrieved from prepare_data().
The sport at which the incremental test was performed. One of cycling, running, or swimming.
A scalar from 0 to 1 indicating the percentage of the data that you would like to
restrain for fitting the Log-Log method. For example, 1 means no restriction (fits using the whole data), and 0.5 means that
only the first 50% of the data will be used. Default to 1.
A boolean to indicate whether to generate a plot from each one of the methods.