helper_dmax_moddmax: Helper - ModDmax
Description
For internal use only and it won't be exported.
Usage
helper_dmax_moddmax(data_prepared, sport, plot)
Arguments
- data_prepared
The data retrieved from prepare_data().
- sport
The sport at which the incremental test was performed. One of cycling, running, or swimming.
- plot
A boolean to indicate whether to generate a plot from each one of the methods.