This is an obligatory step before applying any lactate threshold method. This function will model the raw data as well as make all the necessary data wrangling.
prepare_fit(
.data,
fit = c("3rd degree polynomial", "4th degree polynomial", "B-spline", "Exponential"),
include_baseline = FALSE,
sport = c("cycling", "running", "swimming")
)a tibble with the following nested columns:
The raw data.
The interpolated data.
The model chosen in the fit parameter.
The augmented data retrieved from the model.
A boolean indicating the include_baseline argument.
The data retrieved from prepare_data().
The fit you would like to use for finding the lactate values associated to each one of the lactate thresholds.
Please, note that a few lactate thresholds have default methods for this and cannot be changed. See Details.
A boolean to indicate whether to include the baseline value in the fit.
The sport at which the incremental test was performed. One of cycling, running, or swimming.