This is a function for internal use only and it won't be exported.
prepare_fit_dmax_mods(
.data,
fit = c("3rd degree polynomial", "Exponential"),
intensity_to_start,
sport = c("cycling", "running", "swimming")
)a tibble with the following nested columns:
The raw data.
The interpolated data.
The model chosen in the fit parameter.
The augmented data retrieved from the model.
A boolean indicating the include_baseline argument.
The data retrieved from prepare_data().
The fit you would like to use for finding the lactate values associated to each one of the lactate thresholds.
Please, note that a few lactate thresholds have default methods for this and cannot be changed. See Details.
A double indicating the intensity to start the fit.
The sport at which the incremental test was performed. One of cycling, running, or swimming.