Learn R Programming

lactater (version 0.2.0)

retrieve_heart_rate: Retrieve heart rate

Description

Retrieves the heart rate associated to a given intensity value. It is mainly for internal use but it is exported for possible extensions.

Usage

retrieve_heart_rate(raw_data, intensity_value)

Value

the heart rate associated with the estimated lactate threshold

Arguments

raw_data

The raw data.

intensity_value

The intensity value.