For internal use only and it won't be exported.
bsln_plus_helper(.data, data_augmented, fit, model, plus)The results (intensity, lactate, heart rate) from the lactate threshold method.
The raw data.
The augmented data from the model.
The fit you would like to use for finding the lactate values associated to each one of the lactate thresholds.
The model chosen in fit,
The plus value to be added to the baseline value.