retrieve_lactate: Retrieve lactate
Description
Retrieves the lactate associated to a given intensity value.
It is mainly for internal use but it is exported for possible extensions.
Usage
retrieve_lactate(model, intensity_value)
Value
the lactate associated with the estimated lactate threshold
Arguments
- model
The model chosen in fit.
- intensity_value
The intensity value.